==> pyglossary_4.5.0.orig.tar.gz: pyglossary-4.5.0/doc/p/dicformids.md <==
## DictionaryForMIDs

### General Information

| Attribute       | Value                                                                    |
| --------------- | ------------------------------------------------------------------------ |
| Name            | Dicformids                                                               |
| snake_case_name | dicformids                                                               |
| Description     | DictionaryForMIDs                                                        |
| Extensions      | `.mids`                                                                  |
| Read support    | Yes                                                                      |
| Write support   | Yes                                                                      |
| Single-file     | No                                                                       |
| Kind            | 📁 directory                                                              |
| Sort-on-write   | always                                                                   |
| Sort key        | `dicformids`                                                             |
| Wiki            | ―                                                                        |
| Website         | [DictionaryForMIDs - SourceForge](http://dictionarymid.sourceforge.net/) |



### Dictionary Applications/Tools

| Name & Website                                             | License | Platforms                         |
| ---------------------------------------------------------- | ------- | --------------------------------- |
| [DictionaryForMIDs](http://dictionarymid.sourceforge.net/) | GPL     | Android, Web, Windows, Linux, Mac |

==> pyglossary_5.0.9.orig.tar.gz: pyglossary-5.0.9/doc/p/dicformids.md <==
## DictionaryForMIDs

### General Information

| Attribute       | Value                                                                    |
| --------------- | ------------------------------------------------------------------------ |
| Name            | Dicformids                                                               |
| snake_case_name | dicformids                                                               |
| Description     | DictionaryForMIDs                                                        |
| Extensions      | `.mids`                                                                  |
| Read support    | Yes                                                                      |
| Write support   | Yes                                                                      |
| Single-file     | No                                                                       |
| Kind            | 📁 directory                                                              |
| Sort-on-write   | Always                                                                   |
| Sort key        | `dicformids`                                                             |
| Wiki            | ―                                                                        |
| Website         | [DictionaryForMIDs - SourceForge](http://dictionarymid.sourceforge.net/) |

### Dictionary Applications/Tools

| Name & Website                                             | Source code | License | Platforms                         | Language |
| ---------------------------------------------------------- | ----------- | ------- | --------------------------------- | -------- |
| [DictionaryForMIDs](http://dictionarymid.sourceforge.net/) | ―           | GPL     | Android, Web, Windows, Linux, Mac | Java     |
